@@ -9,11 +9,11 @@ Test::Valgrind::Parser::Text - Parse valgrind output as a text stream.
 
 =head1 VERSION
 
-Version 1.13
+Version 1.14
 
 =cut
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 =head1 DESCRIPTION
 
@@ -25,7 +25,9 @@ use base qw<Test::Valgrind::Parser>;
 
 =head1 METHODS
 
-=head2 C<args $session, $fh>
+=head2 C<args>
+
+    my @args = $tvp->args($session, $fh);
 
 Returns the arguments needed to tell C<valgrind> to print in text to the filehandle C<$fh>.
 
@@ -64,7 +66,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009,2010,2011 Vincent Pit, all rights reserved.
+Copyright 2009,2010,2011,2013 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
